"""This module provides utilities to push logs to ElasticSearch"""

from __future__ import absolute_import, division, print_function

from jobcontrol import callback
import logging


class JobControlHandler(logging.Handler):
    """Logging handler which pushes logs to the JobControl REST service,
    persisting them in ElasticSearch"""

    def __init__(self,
                 level=logging.NOTSET,
                 baseurl=callback.CALLBACK_BASE_URL):

        super(JobControlHandler, self).__init__(level=level)
        self.cbc = callback.CallbackClient(baseurl=baseurl)


    def emit(self, record):

        if record.jobrun_id is not None and record.jobrun_action_id is not None:

            if record.input_product is None:
                self.cbc.add_jobrun_action_log(record.jobrun_id, record.jobrun_action_id,
                                               self.format(record))
            else:
                self.cbc.add_jobrun_action_product_log(record.jobrun_id, record.jobrun_action_id,
                                                       record.input_product.reference,
                                                       self.format(record))


class JobControlAdapter(logging.LoggerAdapter):

    def __init__(self, logger, jobrun_id, jobrun_action_id,
                 input_product=None):

        extra = {'jobrun_id': jobrun_id,
                 'jobrun_action_id': jobrun_action_id,
                 'input_product': input_product}

        super(JobControlAdapter, self).__init__(logger, extra)
